==> ejc-salary-api-3.0.0-20241028.095235-57-sources.jar: com/ejianc/business/salary/vo/PayableDetailVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应发工资上传明细
 * 
 * @author generator
 * 
 */
public class PayableDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long payableId; // 主表id
    private Long detailEmployeeId; // 员工主键
    private String detailEmployeeName; // 员工名称
    private String detailEmployeeCode; // 员工编码
    private String idCard; // 证件号码
    private String jobType; // 岗位性质
    private Long detailOrgId; // 单位id
    private String detailOrgName; // 单位名称
    private String detailOrgCode; // 单位编码
    private String job; // 岗位
    private String dept; // 部门
    private String jobLevel; // 岗级
    private String sbjnOrgName; // 社保缴纳单位名称
    private String sbjnOrgCode; // 社保缴纳单位编码
    private String isMove; // 本月是否发生调动：1是,2-否
    private Long sbcdOrgId; // 社保承担单位id
    private String sbcdOrgName; // 社保承担单位名称
    private String sbcdOrgCode; // 社保承担单位编码
    private Long gzffOrgId; // 工资发放单位id
    private String gzffOrgName; // 工资发放单位名称
    private String gzffOrgCode; // 工资发放单位编码
    private BigDecimal unWriteOffMny; // 截止当前未核销金额
    private BigDecimal writeOffMny; // 本次核销金额
    private BigDecimal yfjsMny; // 应发计税
    private BigDecimal yfmsMny; // 应发免税
    private BigDecimal jobMny; // 岗位工资
    private BigDecimal performanceMny; // 绩效工资
    private BigDecimal workYearMny; // 司龄补贴
    private BigDecimal workTypeMny; // 职称补贴
    private BigDecimal certificateMny; // 证书补贴
    private BigDecimal travelMny; // 派驻补贴
    private BigDecimal trafficMny; // 交通补贴
    private BigDecimal mealMny; // 餐补
    private BigDecimal benefitMny; // 福利费
    private BigDecimal holidayMny; // 过节费
    private BigDecimal yearEndMny; // 年终奖
    private BigDecimal overtimeMny; // 加班费
    private BigDecimal addMny; // 补款
    private BigDecimal buttonMny; // 扣款
    private BigDecimal salaryMny; // 工资合计
    private BigDecimal yfSalaryMny; // 应发工资
    private BigDecimal yfmsSalaryMny; // 应发+免税
    private BigDecimal orgSalaryMny; // 个人本单位累计
    private BigDecimal orgsSalaryMny; // 个人所有单位累计
    private BigDecimal taxYfmsMny; // 个税计算、工资单应发免税
    private String memo; // 备注

    private String errorMsg; // 导入错误信息

    private Integer detailCollectStatus; // 汇总状态（0-未汇总，1--已汇总,2-被驳回）


    public Integer getDetailCollectStatus() {
        return detailCollectStatus;
    }

    public void setDetailCollectStatus(Integer detailCollectStatus) {
        this.detailCollectStatus = detailCollectStatus;
    }
    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
    public Long getPayableId() {
        return payableId;
    }

    public void setPayableId(Long payableId) {
        this.payableId = payableId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getJobType() {
        return jobType;
    }

    public void setJobType(String jobType) {
        this.jobType = jobType;
    }
    public Long getDetailOrgId() {
        return detailOrgId;
    }

    public void setDetailOrgId(Long detailOrgId) {
        this.detailOrgId = detailOrgId;
    }
    public String getDetailOrgName() {
        return detailOrgName;
    }

    public void setDetailOrgName(String detailOrgName) {
        this.detailOrgName = detailOrgName;
    }
    public String getDetailOrgCode() {
        return detailOrgCode;
    }

    public void setDetailOrgCode(String detailOrgCode) {
        this.detailOrgCode = detailOrgCode;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getDept() {
        return dept;
    }

    public void setDept(String dept) {
        this.dept = dept;
    }
    public String getJobLevel() {
        return jobLevel;
    }

    public void setJobLevel(String jobLevel) {
        this.jobLevel = jobLevel;
    }
    public String getSbjnOrgName() {
        return sbjnOrgName;
    }

    public void setSbjnOrgName(String sbjnOrgName) {
        this.sbjnOrgName = sbjnOrgName;
    }
    public String getSbjnOrgCode() {
        return sbjnOrgCode;
    }

    public void setSbjnOrgCode(String sbjnOrgCode) {
        this.sbjnOrgCode = sbjnOrgCode;
    }
    public String getIsMove() {
        return isMove;
    }

    public void setIsMove(String isMove) {
        this.isMove = isMove;
    }
    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }
    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }
    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
    public Long getGzffOrgId() {
        return gzffOrgId;
    }

    public void setGzffOrgId(Long gzffOrgId) {
        this.gzffOrgId = gzffOrgId;
    }
    public String getGzffOrgName() {
        return gzffOrgName;
    }

    public void setGzffOrgName(String gzffOrgName) {
        this.gzffOrgName = gzffOrgName;
    }
    public String getGzffOrgCode() {
        return gzffOrgCode;
    }

    public void setGzffOrgCode(String gzffOrgCode) {
        this.gzffOrgCode = gzffOrgCode;
    }
    public BigDecimal getUnWriteOffMny() {
        return unWriteOffMny;
    }

    public void setUnWriteOffMny(BigDecimal unWriteOffMny) {
        this.unWriteOffMny = unWriteOffMny;
    }
    public BigDecimal getWriteOffMny() {
        return writeOffMny;
    }

    public void setWriteOffMny(BigDecimal writeOffMny) {
        this.writeOffMny = writeOffMny;
    }
    public BigDecimal getYfjsMny() {
        return yfjsMny;
    }

    public void setYfjsMny(BigDecimal yfjsMny) {
        this.yfjsMny = yfjsMny;
    }
    public BigDecimal getYfmsMny() {
        return yfmsMny;
    }

    public void setYfmsMny(BigDecimal yfmsMny) {
        this.yfmsMny = yfmsMny;
    }
    public BigDecimal getJobMny() {
        return jobMny;
    }

    public void setJobMny(BigDecimal jobMny) {
        this.jobMny = jobMny;
    }
    public BigDecimal getPerformanceMny() {
        return performanceMny;
    }

    public void setPerformanceMny(BigDecimal performanceMny) {
        this.performanceMny = performanceMny;
    }
    public BigDecimal getWorkYearMny() {
        return workYearMny;
    }

    public void setWorkYearMny(BigDecimal workYearMny) {
        this.workYearMny = workYearMny;
    }
    public BigDecimal getWorkTypeMny() {
        return workTypeMny;
    }

    public void setWorkTypeMny(BigDecimal workTypeMny) {
        this.workTypeMny = workTypeMny;
    }
    public BigDecimal getCertificateMny() {
        return certificateMny;
    }

    public void setCertificateMny(BigDecimal certificateMny) {
        this.certificateMny = certificateMny;
    }
    public BigDecimal getTravelMny() {
        return travelMny;
    }

    public void setTravelMny(BigDecimal travelMny) {
        this.travelMny = travelMny;
    }
    public BigDecimal getTrafficMny() {
        return trafficMny;
    }

    public void setTrafficMny(BigDecimal trafficMny) {
        this.trafficMny = trafficMny;
    }
    public BigDecimal getMealMny() {
        return mealMny;
    }

    public void setMealMny(BigDecimal mealMny) {
        this.mealMny = mealMny;
    }
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    public BigDecimal getHolidayMny() {
        return holidayMny;
    }

    public void setHolidayMny(BigDecimal holidayMny) {
        this.holidayMny = holidayMny;
    }
    public BigDecimal getYearEndMny() {
        return yearEndMny;
    }

    public void setYearEndMny(BigDecimal yearEndMny) {
        this.yearEndMny = yearEndMny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getAddMny() {
        return addMny;
    }

    public void setAddMny(BigDecimal addMny) {
        this.addMny = addMny;
    }
    public BigDecimal getButtonMny() {
        return buttonMny;
    }

    public void setButtonMny(BigDecimal buttonMny) {
        this.buttonMny = buttonMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getYfSalaryMny() {
        return yfSalaryMny;
    }

    public void setYfSalaryMny(BigDecimal yfSalaryMny) {
        this.yfSalaryMny = yfSalaryMny;
    }
    public BigDecimal getYfmsSalaryMny() {
        return yfmsSalaryMny;
    }

    public void setYfmsSalaryMny(BigDecimal yfmsSalaryMny) {
        this.yfmsSalaryMny = yfmsSalaryMny;
    }
    public BigDecimal getOrgSalaryMny() {
        return orgSalaryMny;
    }

    public void setOrgSalaryMny(BigDecimal orgSalaryMny) {
        this.orgSalaryMny = orgSalaryMny;
    }
    public BigDecimal getOrgsSalaryMny() {
        return orgsSalaryMny;
    }

    public void setOrgsSalaryMny(BigDecimal orgsSalaryMny) {
        this.orgsSalaryMny = orgsSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getTaxYfmsMny() {
        return taxYfmsMny;
    }

    public void setTaxYfmsMny(BigDecimal taxYfmsMny) {
        this.taxYfmsMny = taxYfmsMny;
    }
}

==> ejc-salary-api-3.0.0-20241112.101621-62-sources.jar: com/ejianc/business/salary/vo/PayableDetailVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应发工资上传明细
 * 
 * @author generator
 * 
 */
public class PayableDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long payableId; // 主表id
    private Long detailEmployeeId; // 员工主键
    private String detailEmployeeName; // 员工名称
    private String detailEmployeeCode; // 员工编码
    private String idCard; // 证件号码
    private String jobType; // 岗位性质
    private Long detailOrgId; // 单位id
    private String detailOrgName; // 单位名称
    private String detailOrgCode; // 单位编码
    private String job; // 岗位
    private String dept; // 部门
    private String jobLevel; // 岗级
    private String sbjnOrgName; // 社保缴纳单位名称
    private String sbjnOrgCode; // 社保缴纳单位编码
    private String isMove; // 本月是否发生调动：1是,2-否
    private Long sbcdOrgId; // 社保承担单位id
    private String sbcdOrgName; // 社保承担单位名称
    private String sbcdOrgCode; // 社保承担单位编码
    private Long gzffOrgId; // 工资发放单位id
    private String gzffOrgName; // 工资发放单位名称
    private String gzffOrgCode; // 工资发放单位编码
    private BigDecimal unWriteOffMny; // 截止当前未核销金额
    private BigDecimal writeOffMny; // 本次核销金额
    private BigDecimal yfjsMny; // 应发计税
    private BigDecimal yfmsMny; // 应发免税
    private BigDecimal jobMny; // 岗位工资
    private BigDecimal performanceMny; // 绩效工资
    private BigDecimal workYearMny; // 司龄补贴
    private BigDecimal workTypeMny; // 职称补贴
    private BigDecimal certificateMny; // 证书补贴
    private BigDecimal travelMny; // 派驻补贴
    private BigDecimal trafficMny; // 交通补贴
    private BigDecimal mealMny; // 餐补
    private BigDecimal benefitMny; // 福利费
    private BigDecimal holidayMny; // 过节费
    private BigDecimal yearEndMny; // 年终奖
    private BigDecimal overtimeMny; // 加班费
    private BigDecimal addMny; // 补款
    private BigDecimal buttonMny; // 扣款
    private BigDecimal salaryMny; // 工资合计
    private BigDecimal yfSalaryMny; // 应发工资
    private BigDecimal yfmsSalaryMny; // 应发+免税
    private BigDecimal orgSalaryMny; // 个人本单位累计
    private BigDecimal orgsSalaryMny; // 个人所有单位累计
    private BigDecimal taxYfmsMny; // 个税计算、工资单应发免税
    private String memo; // 备注

    private String errorMsg; // 导入错误信息

    private Integer detailCollectStatus; // 汇总状态（0-未汇总，1--已汇总,2-被驳回）
    private Long sbcdCompanyId; // 社保承担公司id
    private String sbcdCompanyCode; // 社保承担公司编号
    private String sbcdCompanyName; // 社保承担公司


    public Long getSbcdCompanyId() {
        return sbcdCompanyId;
    }

    public void setSbcdCompanyId(Long sbcdCompanyId) {
        this.sbcdCompanyId = sbcdCompanyId;
    }

    public String getSbcdCompanyCode() {
        return sbcdCompanyCode;
    }

    public void setSbcdCompanyCode(String sbcdCompanyCode) {
        this.sbcdCompanyCode = sbcdCompanyCode;
    }

    public String getSbcdCompanyName() {
        return sbcdCompanyName;
    }

    public void setSbcdCompanyName(String sbcdCompanyName) {
        this.sbcdCompanyName = sbcdCompanyName;
    }

    public Integer getDetailCollectStatus() {
        return detailCollectStatus;
    }

    public void setDetailCollectStatus(Integer detailCollectStatus) {
        this.detailCollectStatus = detailCollectStatus;
    }
    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
    public Long getPayableId() {
        return payableId;
    }

    public void setPayableId(Long payableId) {
        this.payableId = payableId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getJobType() {
        return jobType;
    }

    public void setJobType(String jobType) {
        this.jobType = jobType;
    }
    public Long getDetailOrgId() {
        return detailOrgId;
    }

    public void setDetailOrgId(Long detailOrgId) {
        this.detailOrgId = detailOrgId;
    }
    public String getDetailOrgName() {
        return detailOrgName;
    }

    public void setDetailOrgName(String detailOrgName) {
        this.detailOrgName = detailOrgName;
    }
    public String getDetailOrgCode() {
        return detailOrgCode;
    }

    public void setDetailOrgCode(String detailOrgCode) {
        this.detailOrgCode = detailOrgCode;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getDept() {
        return dept;
    }

    public void setDept(String dept) {
        this.dept = dept;
    }
    public String getJobLevel() {
        return jobLevel;
    }

    public void setJobLevel(String jobLevel) {
        this.jobLevel = jobLevel;
    }
    public String getSbjnOrgName() {
        return sbjnOrgName;
    }

    public void setSbjnOrgName(String sbjnOrgName) {
        this.sbjnOrgName = sbjnOrgName;
    }
    public String getSbjnOrgCode() {
        return sbjnOrgCode;
    }

    public void setSbjnOrgCode(String sbjnOrgCode) {
        this.sbjnOrgCode = sbjnOrgCode;
    }
    public String getIsMove() {
        return isMove;
    }

    public void setIsMove(String isMove) {
        this.isMove = isMove;
    }
    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }
    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }
    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
    public Long getGzffOrgId() {
        return gzffOrgId;
    }

    public void setGzffOrgId(Long gzffOrgId) {
        this.gzffOrgId = gzffOrgId;
    }
    public String getGzffOrgName() {
        return gzffOrgName;
    }

    public void setGzffOrgName(String gzffOrgName) {
        this.gzffOrgName = gzffOrgName;
    }
    public String getGzffOrgCode() {
        return gzffOrgCode;
    }

    public void setGzffOrgCode(String gzffOrgCode) {
        this.gzffOrgCode = gzffOrgCode;
    }
    public BigDecimal getUnWriteOffMny() {
        return unWriteOffMny;
    }

    public void setUnWriteOffMny(BigDecimal unWriteOffMny) {
        this.unWriteOffMny = unWriteOffMny;
    }
    public BigDecimal getWriteOffMny() {
        return writeOffMny;
    }

    public void setWriteOffMny(BigDecimal writeOffMny) {
        this.writeOffMny = writeOffMny;
    }
    public BigDecimal getYfjsMny() {
        return yfjsMny;
    }

    public void setYfjsMny(BigDecimal yfjsMny) {
        this.yfjsMny = yfjsMny;
    }
    public BigDecimal getYfmsMny() {
        return yfmsMny;
    }

    public void setYfmsMny(BigDecimal yfmsMny) {
        this.yfmsMny = yfmsMny;
    }
    public BigDecimal getJobMny() {
        return jobMny;
    }

    public void setJobMny(BigDecimal jobMny) {
        this.jobMny = jobMny;
    }
    public BigDecimal getPerformanceMny() {
        return performanceMny;
    }

    public void setPerformanceMny(BigDecimal performanceMny) {
        this.performanceMny = performanceMny;
    }
    public BigDecimal getWorkYearMny() {
        return workYearMny;
    }

    public void setWorkYearMny(BigDecimal workYearMny) {
        this.workYearMny = workYearMny;
    }
    public BigDecimal getWorkTypeMny() {
        return workTypeMny;
    }

    public void setWorkTypeMny(BigDecimal workTypeMny) {
        this.workTypeMny = workTypeMny;
    }
    public BigDecimal getCertificateMny() {
        return certificateMny;
    }

    public void setCertificateMny(BigDecimal certificateMny) {
        this.certificateMny = certificateMny;
    }
    public BigDecimal getTravelMny() {
        return travelMny;
    }

    public void setTravelMny(BigDecimal travelMny) {
        this.travelMny = travelMny;
    }
    public BigDecimal getTrafficMny() {
        return trafficMny;
    }

    public void setTrafficMny(BigDecimal trafficMny) {
        this.trafficMny = trafficMny;
    }
    public BigDecimal getMealMny() {
        return mealMny;
    }

    public void setMealMny(BigDecimal mealMny) {
        this.mealMny = mealMny;
    }
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    public BigDecimal getHolidayMny() {
        return holidayMny;
    }

    public void setHolidayMny(BigDecimal holidayMny) {
        this.holidayMny = holidayMny;
    }
    public BigDecimal getYearEndMny() {
        return yearEndMny;
    }

    public void setYearEndMny(BigDecimal yearEndMny) {
        this.yearEndMny = yearEndMny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getAddMny() {
        return addMny;
    }

    public void setAddMny(BigDecimal addMny) {
        this.addMny = addMny;
    }
    public BigDecimal getButtonMny() {
        return buttonMny;
    }

    public void setButtonMny(BigDecimal buttonMny) {
        this.buttonMny = buttonMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getYfSalaryMny() {
        return yfSalaryMny;
    }

    public void setYfSalaryMny(BigDecimal yfSalaryMny) {
        this.yfSalaryMny = yfSalaryMny;
    }
    public BigDecimal getYfmsSalaryMny() {
        return yfmsSalaryMny;
    }

    public void setYfmsSalaryMny(BigDecimal yfmsSalaryMny) {
        this.yfmsSalaryMny = yfmsSalaryMny;
    }
    public BigDecimal getOrgSalaryMny() {
        return orgSalaryMny;
    }

    public void setOrgSalaryMny(BigDecimal orgSalaryMny) {
        this.orgSalaryMny = orgSalaryMny;
    }
    public BigDecimal getOrgsSalaryMny() {
        return orgsSalaryMny;
    }

    public void setOrgsSalaryMny(BigDecimal orgsSalaryMny) {
        this.orgsSalaryMny = orgsSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getTaxYfmsMny() {
        return taxYfmsMny;
    }

    public void setTaxYfmsMny(BigDecimal taxYfmsMny) {
        this.taxYfmsMny = taxYfmsMny;
    }
}
